==> haskell-src-meta-0.8.15-84.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-meta
version:              0.8.15
visibility:           public
id:                   haskell-src-meta-0.8.15-GqSWx9monJhDwN3u4roT6d
key:                  haskell-src-meta-0.8.15-GqSWx9monJhDwN3u4roT6d
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  ecbec401bcf1a5e63577acffbff70992
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/haskell-src-meta-0.8.15
library-dirs:         /usr/lib/ghc-9.6.6/site-local/haskell-src-meta-0.8.15
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/haskell-src-meta-0.8.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.15-GqSWx9monJhDwN3u4roT6d
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-F3jL8MeOgpf1H3BDGTEVcV
    pretty-1.1.3.6 syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt
    template-haskell-2.20.0.0 th-orphans-0.13.16-x2p4Pj1aYA6bkrdDunvhC

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.15-85-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-meta
version:              0.8.15
visibility:           public
id:                   haskell-src-meta-0.8.15-5WA14dofYHdB0COx7SkwL2
key:                  haskell-src-meta-0.8.15-5WA14dofYHdB0COx7SkwL2
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  7f76dc1e978f73d3021213d7a4a8026a
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/haskell-src-meta-0.8.15
library-dirs:         /usr/lib/ghc-9.6.6/site-local/haskell-src-meta-0.8.15
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/haskell-src-meta-0.8.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.15-5WA14dofYHdB0COx7SkwL2
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-63590nDmfj1880iQCS4JdS
    pretty-1.1.3.6 syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp
    template-haskell-2.20.0.0 th-orphans-0.13.16-7vRRXCTUh27LcIJ3KgMdVn

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
